@@ -46,8 +46,8 @@ class QRangeSlider(_HookedSlider, QSlider):
 
     _NULL_CTRL = ("None", -1)
 
-    def __init__(self, *args):
-        super().__init__(*args)
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
 
         # list of values
         self._value: List[int] = [20, 80]
@@ -69,6 +69,8 @@ class QRangeSlider(_HookedSlider, QSlider):
         self._repeatMultiplier = 1  # TODO
         # for wheel nav
         self._offset_accum = 0
+        # fraction of total range to scroll when holding Ctrl while scrolling
+        self._control_fraction = 0.04
 
         # color
         self._style = RangeSliderStyle()
@@ -483,11 +485,12 @@ class QRangeSlider(_HookedSlider, QSlider):
 
     def _neighbor_bound(self, val: int, index: int, _lst: List[int]) -> int:
         # make sure we don't go lower than any preceding index:
+        min_dist = self._post_get_hook(self.singleStep())
         if index > 0:
-            val = max(_lst[index - 1], val)
+            val = max(_lst[index - 1] + min_dist, val)
         # make sure we don't go higher than any following index:
-        if index < len(_lst) - 1:
-            val = min(_lst[index + 1], val)
+        if index < (len(_lst) - 1):
+            val = min(_lst[index + 1] - min_dist, val)
         return val
 
     def wheelEvent(self, e: QtGui.QWheelEvent) -> None:
@@ -501,9 +504,7 @@ class QRangeSlider(_HookedSlider, QSlider):
         if self._scrollByDelta(orientation, e.modifiers(), delta):
             e.accept()
 
-    def _scrollByDelta(
-        self, orientation, modifiers: Qt.KeyboardModifiers, delta: int
-    ) -> bool:
+    def _scrollByDelta(self, orientation, modifiers, delta: int) -> bool:
         steps_to_scroll = 0
         pg_step = self.pageStep()
 
@@ -511,10 +512,17 @@ class QRangeSlider(_HookedSlider, QSlider):
         if orientation == Qt.Horizontal:
             delta *= -1
         offset = delta / 120
-        if modifiers & Qt.ControlModifier or modifiers & Qt.ShiftModifier:
+        if modifiers & Qt.ShiftModifier:
             # Scroll one page regardless of delta:
             steps_to_scroll = _bound(-pg_step, pg_step, int(offset * pg_step))
             self._offset_accum = 0
+        elif modifiers & Qt.ControlModifier:
+            # Scroll one page regardless of delta:
+            _range = self._pre_set_hook(self.maximum()) - self._pre_set_hook(
+                self.minimum()
+            )
+            steps_to_scroll = offset * _range * self._control_fraction
+            self._offset_accum = 0
         else:
             # Calculate how many lines to scroll. Depending on what delta is (and
             # offset), we might end up with a fraction (e.g. scroll 1.3 lines). We can
