@@ -3,8 +3,10 @@ import re
 from dataclasses import dataclass, replace
 from typing import TYPE_CHECKING, Union
 
+from .qtcompat import PYQT_VERSION
 from .qtcompat.QtCore import Qt
 from .qtcompat.QtGui import (
+    QBrush,
     QColor,
     QGradient,
     QLinearGradient,
@@ -33,24 +35,40 @@ class RangeSliderStyle:
     h_offset: float = None
     has_stylesheet: bool = False
 
-    def brush(self, opt: QStyleOptionSlider) -> Union[QGradient, QColor]:
+    def brush(self, opt: QStyleOptionSlider) -> QBrush:
         cg = opt.palette.currentColorGroup()
         attr = {
             QPalette.Active: "brush_active",  # 0
             QPalette.Disabled: "brush_disabled",  # 1
             QPalette.Inactive: "brush_inactive",  # 2
         }[cg]
-        val = getattr(self, attr) or getattr(SYSTEM_STYLE, attr)
-        if isinstance(val, str):
-            val = QColor(val)
+        _val = getattr(self, attr)
+        if not _val:
+            if self.has_stylesheet:
+                # if someone set a general style sheet but didn't specify
+                # :active, :inactive, etc... then Qt just uses whatever they
+                # DID specify
+                for i in ("active", "inactive", "disabled"):
+                    _val = getattr(self, f"brush_{i}")
+                    if _val:
+                        break
+            else:
+                _val = getattr(SYSTEM_STYLE, attr)
 
-        if not val:
-            return Qt.NoBrush
+        if _val is None:
+            return QBrush()
+
+        if isinstance(_val, str):
+            val = QColor(_val)
+            if not val.isValid():
+                val = parse_color(_val, default_attr=attr)
+        else:
+            val = _val
 
         if opt.tickPosition != QSlider.NoTicks:
             val.setAlphaF(self.tick_bar_alpha or SYSTEM_STYLE.tick_bar_alpha)
 
-        return val
+        return QBrush(val)
 
     def pen(self, opt: QStyleOptionSlider) -> Union[Qt.PenStyle, QColor]:
         cg = opt.palette.currentColorGroup()
@@ -77,9 +95,9 @@ class RangeSliderStyle:
                 off += self.h_offset or SYSTEM_STYLE.h_offset or 0
             else:
                 off += self.v_offset or SYSTEM_STYLE.v_offset or 0
-            if tp & QSlider.TicksAbove:
+            if tp == QSlider.TicksAbove:
                 off += self.tick_offset or SYSTEM_STYLE.tick_offset
-            elif tp & QSlider.TicksBelow:
+            elif tp == QSlider.TicksBelow:
                 off -= self.tick_offset or SYSTEM_STYLE.tick_offset
         return off
 
@@ -119,6 +137,9 @@ CATALINA_STYLE = replace(
     tick_offset=4,
 )
 
+if PYQT_VERSION and int(PYQT_VERSION.split(".")[0]) == 6:
+    CATALINA_STYLE = replace(CATALINA_STYLE, tick_offset=2)
+
 BIG_SUR_STYLE = replace(
     CATALINA_STYLE,
     brush_active="#0A81FE",
@@ -131,6 +152,9 @@ BIG_SUR_STYLE = replace(
     tick_bar_alpha=0.2,
 )
 
+if PYQT_VERSION and int(PYQT_VERSION.split(".")[0]) == 6:
+    BIG_SUR_STYLE = replace(BIG_SUR_STYLE, tick_offset=-3)
+
 WINDOWS_STYLE = replace(
     BASE_STYLE,
     brush_active="#550179D7",
@@ -202,7 +226,7 @@ rgba_pattern = re.compile(
 )
 
 
-def parse_color(color: str) -> Union[str, QGradient]:
+def parse_color(color: str, default_attr) -> Union[QColor, QGradient]:
     qc = QColor(color)
     if qc.isValid():
         return qc
@@ -229,7 +253,7 @@ def parse_color(color: str) -> Union[str, QGradient]:
         return grad
 
     # fallback to dark gray
-    return "#333"
+    return QColor(getattr(SYSTEM_STYLE, default_attr))
 
 
 def update_styles_from_stylesheet(obj: "QRangeSlider"):
@@ -240,25 +264,8 @@ def update_styles_from_stylesheet(obj: "QRangeSlider"):
         qss = parent.styleSheet() + qss
         parent = parent.parent()
     qss = QApplication.instance().styleSheet() + qss
-
-    # obj._style.has_stylesheet = False
-
-    # # Find bar color
-    # # TODO: optional horizontal or vertical
-    # match = re.search(r"Slider::sub-page:?([^{\s]*)?\s*{\s*([^}]+)}", qss, re.S)
-    # if match:
-    #     orientation, content = match.groups()
-    #     for line in reversed(content.splitlines()):
-    #         bgrd = re.search(r"background(-color)?:\s*([^;]+)", line)
-    #         if bgrd:
-    #             color = parse_color(bgrd.groups()[-1])
-    #             obj._style.brush_active = color
-    #             # TODO: parse for inactive and disabled
-    #             obj._style.brush_inactive = color
-    #             obj._style.brush_disabled = color
-    #             obj._style.has_stylesheet = True
-    #             obj.update()
-    #             break
+    if not qss:
+        return
 
     # Find bar height/width
     for orient, dim in (("horizontal", "height"), ("vertical", "width")):
